==> cxf-services-xkms-common-3.0.1-sources.jar: org/apache/cxf/xkms/model/xkms/RecoverResultType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RecoverResultType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="RecoverResultType">
 *   &lt;complexContent>
 *     &lt;extension base="{http://www.w3.org/2002/03/xkms#}ResultType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}KeyBinding" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.w3.org/2002/03/xkms#}PrivateKey" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecoverResultType", propOrder = {
    "keyBinding",
    "privateKey"
})
public class RecoverResultType
    extends ResultType
{

    @XmlElement(name = "KeyBinding")
    protected List<KeyBindingType> keyBinding;
    @XmlElement(name = "PrivateKey")
    protected PrivateKeyType privateKey;

    /**
     * Gets the value of the keyBinding property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the keyBinding property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getKeyBinding().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link KeyBindingType }
     * 
     * 
     */
    public List<KeyBindingType> getKeyBinding() {
        if (keyBinding == null) {
            keyBinding = new ArrayList<KeyBindingType>();
        }
        return this.keyBinding;
    }

    /**
     * Gets the value of the privateKey property.
     * 
     * @return
     *     possible object is
     *     {@link PrivateKeyType }
     *     
     */
    public PrivateKeyType getPrivateKey() {
        return privateKey;
    }

    /**
     * Sets the value of the privateKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrivateKeyType }
     *     
     */
    public void setPrivateKey(PrivateKeyType value) {
        this.privateKey = value;
    }

}

==> cxf-services-xkms-common-3.3.10-sources.jar: org/apache/cxf/xkms/model/xkms/RecoverResultType.java <==

package org.apache.cxf.xkms.model.xkms;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for RecoverResultType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="RecoverResultType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;extension base="{http://www.w3.org/2002/03/xkms#}ResultType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}KeyBinding" maxOccurs="unbounded" minOccurs="0"/&amp;gt;
 *         &amp;lt;element ref="{http://www.w3.org/2002/03/xkms#}PrivateKey" minOccurs="0"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/extension&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "RecoverResultType", propOrder = {
    "keyBinding",
    "privateKey"
})
public class RecoverResultType
    extends ResultType
{

    @XmlElement(name = "KeyBinding")
    protected List<KeyBindingType> keyBinding;
    @XmlElement(name = "PrivateKey")
    protected PrivateKeyType privateKey;

    /**
     * Gets the value of the keyBinding property.
     * 
     * &lt;p&gt;
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a &lt;CODE&gt;set&lt;/CODE&gt; method for the keyBinding property.
     * 
     * &lt;p&gt;
     * For example, to add a new item, do as follows:
     * &lt;pre&gt;
     *    getKeyBinding().add(newItem);
     * &lt;/pre&gt;
     * 
     * 
     * &lt;p&gt;
     * Objects of the following type(s) are allowed in the list
     * {@link KeyBindingType }
     * 
     * 
     */
    public List<KeyBindingType> getKeyBinding() {
        if (keyBinding == null) {
            keyBinding = new ArrayList<KeyBindingType>();
        }
        return this.keyBinding;
    }

    /**
     * Gets the value of the privateKey property.
     * 
     * @return
     *     possible object is
     *     {@link PrivateKeyType }
     *     
     */
    public PrivateKeyType getPrivateKey() {
        return privateKey;
    }

    /**
     * Sets the value of the privateKey property.
     * 
     * @param value
     *     allowed object is
     *     {@link PrivateKeyType }
     *     
     */
    public void setPrivateKey(PrivateKeyType value) {
        this.privateKey = value;
    }

}
